/**
 * Copyright (c) 2011-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.se.xslt.model;

import java.util.Map;

import javax.xml.transform.ErrorListener;
import javax.xml.transform.OutputKeys;
import javax.xml.transform.Templates;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerConfigurationException;
import javax.xml.transform.URIResolver;

import com.ebmwebsourcing.easycommons.pooling.PoolException;
import com.ebmwebsourcing.easycommons.pooling.ResourceHandler;

/**
 * @author Nicolas Oddoux - EBM WebSourcing
 */
public class XsltTransformerResourceHandler implements ResourceHandler<Transformer> {

    private Templates template;
    private URIResolver uriResolver;
    private ErrorListener logErrorListener;
    private XsltConfiguration xsltConfiguration;

    /**
     * Create a XSL transformer resource handler
     * 
     * @param template the XSL template
     * @param uriResolver the URI resolver
     * @param logErrorListener the error listener to log error
     * @param xsltConfiguration the XSLT configuration for the SU
     */
    public XsltTransformerResourceHandler(Templates template, URIResolver uriResolver,
            ErrorListener logErrorListener, XsltConfiguration xsltConfiguration) {
        this.template = template;
        this.uriResolver = uriResolver;
        this.logErrorListener = logErrorListener;
        this.xsltConfiguration = xsltConfiguration;
    }

    @Override
    public void onTake(Transformer transformer) {
        // nothing
    }

    @Override
    public Transformer create() {
        
        try {
            // Create a transformer
            Transformer transformer = this.template.newTransformer();

            transformer.setOutputProperty(OutputKeys.INDENT, "yes");
            transformer.setURIResolver(this.uriResolver);
            transformer.setErrorListener(this.logErrorListener);
            
            // Pass it the XSL parameters from the SU configuration
            Map<String, XslParameterBean> suXslParameters = this.xsltConfiguration.getParamNameToParamBean();
            for (XslParameterBean paramBean : suXslParameters.values())
                transformer.setParameter(paramBean.getName(), paramBean.getValue());
            
            return transformer;
        } catch (TransformerConfigurationException e) {
            throw new PoolException(e);
        }
    }

    @Override
    public void onRelease(Transformer transformer) {
        // nothing
    }
}
