/**
 * Copyright (c) 2008-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.se.xslt.utils;

import java.util.logging.Level;
import java.util.logging.Logger;

import javax.xml.transform.ErrorListener;
import javax.xml.transform.SourceLocator;
import javax.xml.transform.TransformerException;

/**
 * An error listener used to resolve line numbers and log details about errors.
 * @author Vincent Zurczak - EBM WebSourcing
 */
public class LogErrorListener implements ErrorListener {

	/**
	 * The component's logger.
	 */
	private final Logger logger;

	/**
	 * The prefix used for every logged message.
	 */
	private final String logPrefix;


	/**
	 * Constructor.
	 * @param logger the component's logger
	 * @param suName the SU name (used to prefix log messages)
	 */
	public LogErrorListener( Logger logger, String suName ) {
		this.logger = logger;
		this.logPrefix = suName + ": ";
	}


	/*
	 * (non-Javadoc)
	 * @see javax.xml.transform.ErrorListener
	 * #error(javax.xml.transform.TransformerException)
	 */
	public void error( TransformerException e ) throws TransformerException {

		int line = -1;
		SourceLocator locator = e.getLocator();
		if( locator != null )
			line = locator.getLineNumber();

		String msg = "an error was found. " + e.getMessage() + " (line: " + ((line == -1) ? "unresolved" : line) + ").";
		if( this.logger.isLoggable( Level.FINE ))
			this.logger.fine( this.logPrefix + msg );

		throw e;
	}


	/*
	 * (non-Javadoc)
	 * @see javax.xml.transform.ErrorListener
	 * #fatalError(javax.xml.transform.TransformerException)
	 */
	public void fatalError( TransformerException e ) throws TransformerException {

		int line = -1;
		SourceLocator locator = e.getLocator();
		if( locator != null )
			line = locator.getLineNumber();

		String msg = "a fatal error was found. " + e.getMessage() + " (line: " + ((line == -1) ? "unresolved" : line) + ").";
		if( this.logger.isLoggable( Level.FINE ))
			this.logger.fine( this.logPrefix + msg );

		throw e;
	}


	/*
	 * (non-Javadoc)
	 * @see javax.xml.transform.ErrorListener
	 * #warning(javax.xml.transform.TransformerException)
	 */
	public void warning( TransformerException e ) throws TransformerException {

		int line = -1;
		SourceLocator locator = e.getLocator();
		if( locator != null )
			line = locator.getLineNumber();

		String msg = "a warning was found. " + e.getMessage() + " (line: " + ((line == -1) ? "unresolved" : line) + ").";
		if( this.logger.isLoggable( Level.FINE ))
			this.logger.fine( this.logPrefix + msg );

		throw e;
	}
}
